@@ -83,9 +83,12 @@ static char rcsid[] DD_UNUSED = "$Id: cuddAddOp.c,v 1.1.2.1 2010-02-04 10:41:15
 /*---------------------------------------------------------------------------*/
 static CUDD_VALUE_TYPE Cudd_type_error (DdManager *, CUDD_VALUE_TYPE);
 static CUDD_VALUE_TYPE Cudd_fatal_error (DdManager *, const char *);
-static void cudd_addWalkLeavesRecur (void (*op)(CUDD_VALUE_TYPE), DdNode *, st_table *);
+/* NuSMV: add begin */
+static void cudd_addWalkLeavesRecur (DdManager *, void (*op)(void*, CUDD_VALUE_TYPE), DdNode *, st_table *, void*);
+/* WAS: static void cudd_addWalkLeavesRecur (void (*op)(CUDD_VALUE_TYPE), DdNode *, st_table *); */
+/* NuSMV: add end */
 static int addCheckPositiveCube (DdManager *manager, DdNode *cube);
-static DdNode * addAbstractRecur (DdManager * manager, CUDD_VALUE_TYPE (*op)(), DdNode * f, DdNode * cube);
+static DdNode * addAbstractRecur (DdManager * manager, CUDD_VALUE_TYPE (*op)(), DdNode * f, DdNode * cube, void* arg);
 
 /**AutomaticEnd***************************************************************/
 
@@ -111,13 +114,14 @@ Cudd_addApply(
 DdManager       *dd,
 CUDD_VALUE_TYPE (*op)(),
 DdNode          *f,
-DdNode          *g)
+DdNode          *g,
+void            *arg)
 {
     DdNode *res;
 
     do {
 	dd->reordered = 0;
-	res = cudd_addApplyRecur(dd,op,f,g);
+	res = cudd_addApplyRecur(dd,op,f,g,arg);
     } while (dd->reordered == 1);
     return(res);
 
@@ -136,7 +140,7 @@ DdNode          *g)
   SeeAlso     []
 
 ******************************************************************************/
-DdNode * 
+DdNode *
 Cudd_addAnd(
 DdManager *dd,
 DdNode    *f,
@@ -194,7 +198,7 @@ DdNode *g)
   SeeAlso     []
 
 ******************************************************************************/
-DdNode * 
+DdNode *
 Cudd_addOr(
 DdManager *dd,
 DdNode    *f,
@@ -253,7 +257,7 @@ DdNode *g)
   SeeAlso     []
 
 ******************************************************************************/
-DdNode * 
+DdNode *
 Cudd_addNot(
 DdManager * dd,
 DdNode * f)
@@ -274,7 +278,7 @@ DdNode * f)
   Synopsis    [Existentially abstracts all the variables in cube from f.]
 
   Description [Abstracts all the variables in cube from f by applying
-  a given function over all possible values taken by the variables. 
+  a given function over all possible values taken by the variables.
   Returns the abstracted ADD.]
 
   SideEffects [None]
@@ -287,7 +291,8 @@ Cudd_addAbstract(
   DdManager * manager,
   CUDD_VALUE_TYPE (*op)(),
   DdNode * f,
-  DdNode * cube)
+  DdNode * cube,
+  void* arg)
 {
     DdNode *res;
 
@@ -298,7 +303,7 @@ Cudd_addAbstract(
 
     do {
 	manager->reordered = 0;
-	res = addAbstractRecur(manager, op, f, cube);
+	res = addAbstractRecur(manager, op, f, cube, arg);
     } while (manager->reordered == 1);
     return(res);
 
@@ -394,7 +399,7 @@ DdNode *h)
     cuddDeref(res_then);
   } while (dd->reordered == 1);
   return(res);
-}    
+}
 
 /**Function********************************************************************
 
@@ -436,27 +441,42 @@ DdNode * b)
 
 ******************************************************************************/
 
-void 
+void
 Cudd_addWalkLeaves(
-void (*op)(CUDD_VALUE_TYPE),
-DdNode * f)
+ /* NuSMV: add begin */
+DdManager* dd,
+ /* NuSMV: add end */
+void (*op)(void*, CUDD_VALUE_TYPE),
+DdNode * f,
+void* arg)
 {
   st_table *tmp_table;
 
   tmp_table = st_init_table(st_ptrcmp,st_ptrhash);
   if (tmp_table == NULL) {
-    fprintf(stderr,"Cudd_addWalkLeaves: tmp_table == NULL\n");
+    /* NuSMV: add begin */
+    fprintf(dd->err,"Cudd_addWalkLeaves: tmp_table == NULL\n");
+    /* WAS: fprintf(stderr,"Cudd_addWalkLeaves: tmp_table == NULL\n"); */
+    /* NuSMV: add end */
     exit(1);
+
   }
-  cudd_addWalkLeavesRecur(op,f,tmp_table);
+  /* NuSMV: add begin */
+  cudd_addWalkLeavesRecur(dd, op,f,tmp_table, arg);
+  /* WAS: cudd_addWalkLeavesRecur(op,f,tmp_table); */
+  /* NuSMV: add end */
   st_free_table(tmp_table);
 }
 
 static void
 cudd_addWalkLeavesRecur(
-void (*op)(CUDD_VALUE_TYPE),
+ /* NuSMV: add begin */
+DdManager* dd,
+ /* NuSMV: add end */
+void (*op)(void*, CUDD_VALUE_TYPE),
 DdNode * f,
-st_table * tmp_table)
+st_table * tmp_table,
+void* arg)
 {
  /* NuSMV: add begin */
   ptrint mark;
@@ -465,15 +485,25 @@ st_table * tmp_table)
 
   if (st_lookup(tmp_table, (char *)f, (char **)((char*)&mark))) return;
   if (st_insert(tmp_table, (char *)f, (char *)1) == ST_OUT_OF_MEM) {
-    fprintf(stderr,"cudd_addWalkLeavesRecur: ST_OUT_OF_MEM\n");
+    /* NuSMV: add begin */
+    fprintf(dd->err,"cudd_addWalkLeavesRecur: ST_OUT_OF_MEM\n");
+    /* WAS: fprintf(stderr,"cudd_addWalkLeavesRecur: ST_OUT_OF_MEM\n"); */
+    /* NuSMV: add end */
+
     exit(1);
   }
   if (cuddIsConstant(f)) {
-    op((CUDD_VALUE_TYPE)cuddV(f));
+    op(arg, (CUDD_VALUE_TYPE)cuddV(f));
   }
   else {
-    cudd_addWalkLeavesRecur(op, (DdNode *)cuddT(f), tmp_table); 
-    cudd_addWalkLeavesRecur(op, (DdNode *)cuddE(f), tmp_table);
+    /* NuSMV: add begin */
+    cudd_addWalkLeavesRecur(dd, op, (DdNode *)cuddT(f), tmp_table, arg);
+    cudd_addWalkLeavesRecur(dd, op, (DdNode *)cuddE(f), tmp_table, arg);
+    /* WAS:
+       cudd_addWalkLeavesRecur(op, (DdNode *)cuddT(f), tmp_table);
+       cudd_addWalkLeavesRecur(op, (DdNode *)cuddE(f), tmp_table);
+    */
+    /* NuSMV: add end */
   }
 }
 
@@ -522,7 +552,8 @@ cudd_addApplyRecur(
 DdManager *dd,
 CUDD_VALUE_TYPE (*op)(),
 DdNode *f,
-DdNode *g)
+DdNode *g,
+void   *arg)
 {
     DdNode *res,
 	   *fv, *fvn, *gv, *gvn,
@@ -537,7 +568,7 @@ DdNode *g)
     if(cuddIsConstant(f) && cuddIsConstant(g)){
       CUDD_VALUE_TYPE res_n;
 
-      res_n = (*op)(cuddV(f),cuddV(g));
+      res_n = ((CUDD_VALUE_TYPE (*)(CUDD_VALUE_TYPE, CUDD_VALUE_TYPE, void*))op)(cuddV(f),cuddV(g),arg);
       if (res_n == NULL) return(NULL);
       return(cuddUniqueConst(dd,res_n));
     }
@@ -564,11 +595,11 @@ DdNode *g)
 	gv = gvn = g;
     }
 
-    T = cudd_addApplyRecur(dd,op,fv,gv);
+    T = cudd_addApplyRecur(dd,op,fv,gv,arg);
     if (T == NULL) return(NULL);
     cuddRef(T);
 
-    E = cudd_addApplyRecur(dd,op,fvn,gvn);
+    E = cudd_addApplyRecur(dd,op,fvn,gvn,arg);
     if (E == NULL) {
 	Cudd_RecursiveDeref(dd,T);
 	return(NULL);
@@ -626,7 +657,7 @@ DdNode    *g)
 
     if (cuddIsConstant(f)) Cudd_type_error(manager, cuddV(f));
     if (cuddIsConstant(g)) Cudd_type_error(manager, cuddV(g));
-    
+
     /* At this point f and g are not constant. */
     if (f < g) { /* Try to increase cache efficiency. */
 	DdNode *tmp = f;
@@ -720,7 +751,7 @@ DdNode    *g)
 
     if (cuddIsConstant(f)) Cudd_type_error(manager, cuddV(f));
     if (cuddIsConstant(g)) Cudd_type_error(manager, cuddV(g));
-    
+
     /* At this point f and g are not constant. */
     if (f < g) { /* Try to increase cache efficiency. */
 	DdNode *tmp = f;
@@ -919,13 +950,13 @@ DdNode    *g)
   if( f == _true  ) return(g);
 
   HANDLE_FAILURE(dd, f); HANDLE_FAILURE(dd, g);
-        
-  if( cuddIsConstant(f) ) Cudd_type_error(dd, cuddV(f)); 
+
+  if( cuddIsConstant(f) ) Cudd_type_error(dd, cuddV(f));
 
   /* Check cache */
   res = cuddCacheLookup2(dd,Cudd_addIfThen,f,g);
   if (res != NULL) return(res);
-  
+
   topf = cuddI(dd,f->index);
   topg = cuddI(dd,g->index);
 
@@ -1125,20 +1156,14 @@ DdNode    * g)
 /*---------------------------------------------------------------------------*/
 static CUDD_VALUE_TYPE Cudd_type_error(DdManager *dd, CUDD_VALUE_TYPE f)
 {
-  start_parsing_err();
-  fprintf(dd->err,"\ntype error: value = ");
-  print_node(dd->err, f);
-  fprintf(dd->err,"\nExpected a boolean expression\n");
-  finish_parsing_err();
-  return(NULL);
+  dd->type_error_fun(dd, dd->err, f, dd->env_arg);
+  return NULL;
 }
 
 static CUDD_VALUE_TYPE Cudd_fatal_error(DdManager *dd, const char * message)
 {
-  start_parsing_err();
-  fprintf(dd->err,"\nFatal error: %s\n", message);
-  finish_parsing_err();
-  return(NULL);
+  dd->fatal_error_fun(dd, dd->err, message, dd->env_arg);
+  return NULL;
 }
 
 /**Function********************************************************************
@@ -1187,7 +1212,8 @@ addAbstractRecur(
   DdManager * manager,
   CUDD_VALUE_TYPE (*op)(),
   DdNode * f,
-  DdNode * cube)
+  DdNode * cube,
+  void* arg)
 {
     DdNode	*T, *E, *res, *res1, *res2, *_false;
 
@@ -1195,20 +1221,20 @@ addAbstractRecur(
     _false = DD_FALSE(manager);
 
     /* Cube is guaranteed to be a cube at this point. */
-    if (f == _false || cuddIsConstant(cube)) {  
+    if (f == _false || cuddIsConstant(cube)) {
         return(f);
     }
 
     /* Abstract a variable that does not appear in f */
     if (cuddI(manager,f->index) > cuddI(manager,cube->index)) {
-	res1 = addAbstractRecur(manager, op, f, cuddT(cube));
+      res1 = addAbstractRecur(manager, op, f, cuddT(cube), arg);
 	if (res1 == NULL) return(NULL);
 	cuddRef(res1);
 	/* Use the "internal" procedure to be alerted in case of
 	** dynamic reordering. If dynamic reordering occurs, we
 	** have to abort the entire abstraction.
 	*/
-	res = cudd_addApplyRecur(manager,op,res1,res1);
+	res = cudd_addApplyRecur(manager,op,res1,res1,arg);
 	if (res == NULL) {
 	    Cudd_RecursiveDeref(manager,res1);
 	    return(NULL);
@@ -1219,7 +1245,7 @@ addAbstractRecur(
         return(res);
     }
 
-    if ((res = cuddCacheLookup2(manager, (DdNode * (*)())(op+1), f, cube)) != NULL) {
+    if ((res = cuddCacheLookup2(manager, (DdNode * (*)())(((char*)op)+1), f, cube)) != NULL) {
 	return(res);
     }
 
@@ -1228,16 +1254,16 @@ addAbstractRecur(
 
     /* If the two indices are the same, so are their levels. */
     if (f->index == cube->index) {
-	res1 = addAbstractRecur(manager, op, T, cuddT(cube));
+      res1 = addAbstractRecur(manager, op, T, cuddT(cube), arg);
 	if (res1 == NULL) return(NULL);
         cuddRef(res1);
-	res2 = addAbstractRecur(manager, op, E, cuddT(cube));
+	res2 = addAbstractRecur(manager, op, E, cuddT(cube), arg);
 	if (res2 == NULL) {
 	    Cudd_RecursiveDeref(manager,res1);
 	    return(NULL);
 	}
         cuddRef(res2);
-	res = cudd_addApplyRecur(manager, op, res1, res2);
+	res = cudd_addApplyRecur(manager, op, res1, res2, arg);
 	if (res == NULL) {
 	    Cudd_RecursiveDeref(manager,res1);
 	    Cudd_RecursiveDeref(manager,res2);
@@ -1246,14 +1272,16 @@ addAbstractRecur(
 	cuddRef(res);
 	Cudd_RecursiveDeref(manager,res1);
 	Cudd_RecursiveDeref(manager,res2);
-	cuddCacheInsert2(manager, (DdNode * (*)())(op+1), f, cube, res);
+	/* function/void pointer arithmetics is illegal, allowed by
+         * gcc extension */
+	cuddCacheInsert2(manager, (DdNode * (*)())(((char*)op)+1), f, cube, res);
 	cuddDeref(res);
         return(res);
     } else { /* if (cuddI(manager,f->index) < cuddI(manager,cube->index)) */
-	res1 = addAbstractRecur(manager, op, T, cube);
+      res1 = addAbstractRecur(manager, op, T, cube, arg);
 	if (res1 == NULL) return(NULL);
         cuddRef(res1);
-	res2 = addAbstractRecur(manager, op, E, cube);
+	res2 = addAbstractRecur(manager, op, E, cube, arg);
 	if (res2 == NULL) {
 	    Cudd_RecursiveDeref(manager,res1);
 	    return(NULL);
@@ -1267,8 +1295,9 @@ addAbstractRecur(
 	}
 	cuddDeref(res1);
 	cuddDeref(res2);
-	cuddCacheInsert2(manager, (DdNode * (*)())(op+1), f, cube, res);
+	/* pointer arithmetic illegal as a gcc extension */
+	cuddCacheInsert2(manager, (DdNode * (*)())(((char*)op)+1), f, cube, res);
         return(res);
-    }	    
+    }
 
 } /* end of addAbstractRecur */
