@@ -73,7 +73,7 @@
 
 ******************************************************************************/
 
-#ifdef __STDC__
+#if defined(__STDC__)  || defined(_MSC_VER)
 #include <float.h>
 #else
 #define DBL_MAX_EXP 1024
@@ -147,7 +147,7 @@ typedef struct GlobalQueueItem {
     double impactP;
     double impactN;
 } GlobalQueueItem;
- 
+
 typedef struct LocalQueueItem {
     struct LocalQueueItem *next;
     struct LocalQueueItem *cnext;
@@ -158,7 +158,7 @@ typedef struct LocalQueueItem {
 #pragma pointer_size restore
 #endif
 
-    
+
 /*---------------------------------------------------------------------------*/
 /* Variable declarations                                                     */
 /*---------------------------------------------------------------------------*/
@@ -278,14 +278,14 @@ Cudd_OverApprox(
 {
     DdNode *subset, *g;
 
-    g = Cudd_Not(f);    
+    g = Cudd_Not(f);
     do {
 	dd->reordered = 0;
 	subset = cuddUnderApprox(dd, g, numVars, threshold, safe, quality);
     } while (dd->reordered == 1);
-    
+
     return(Cudd_NotCond(subset, (subset != NULL)));
-    
+
 } /* end of Cudd_OverApprox */
 
 
@@ -368,14 +368,14 @@ Cudd_RemapOverApprox(
 {
     DdNode *subset, *g;
 
-    g = Cudd_Not(f);    
+    g = Cudd_Not(f);
     do {
 	dd->reordered = 0;
 	subset = cuddRemapUnderApprox(dd, g, numVars, threshold, quality);
     } while (dd->reordered == 1);
-    
+
     return(Cudd_NotCond(subset, (subset != NULL)));
-    
+
 } /* end of Cudd_RemapOverApprox */
 
 
@@ -467,15 +467,15 @@ Cudd_BiasedOverApprox(
 {
     DdNode *subset, *g;
 
-    g = Cudd_Not(f);    
+    g = Cudd_Not(f);
     do {
 	dd->reordered = 0;
 	subset = cuddBiasedUnderApprox(dd, g, b, numVars, threshold, quality1,
 				      quality0);
     } while (dd->reordered == 1);
-    
+
     return(Cudd_NotCond(subset, (subset != NULL)));
-    
+
 } /* end of Cudd_BiasedOverApprox */
 
 
@@ -1261,7 +1261,7 @@ UAmarkNodes(
 
 /**Function********************************************************************
 
-  Synopsis    [Builds the subset BDD.] 
+  Synopsis    [Builds the subset BDD.]
 
   Description [Builds the subset BDD. Based on the info table,
   replaces selected nodes by zero. Returns a pointer to the result if
