@@ -553,7 +553,7 @@ Cudd_DumpDot(
                   /* WAS: fprintf(fp,"\"%lx\" [label = \"",
                           (mask & (long) scan) / sizeof(DdNode)); */
                 /* NuSMV: add end */
-                print_node(fp, cuddV(scan));
+                dd->print_fun(dd, fp, cuddV(scan), dd->env_arg);
                 retval = fprintf(fp, "\"];\n");
               /* NuSMV: added end */
 		if (retval == EOF) goto failure;
@@ -724,7 +724,7 @@ Cudd_DumpDot(
                           (unsigned long) ((mask & (long) scan) / sizeof(DdNode))); */
                 /* NuSMV: add end */
 
-                retval &= print_node(fp, cuddV(scan));
+                retval &= dd->print_fun(dd, fp, cuddV(scan), dd->env_arg);
                 retval &= fprintf(fp, "\"];\n");
 #endif
     /* NuSMV: added end */
@@ -1352,7 +1352,7 @@ ddDoDumpDaVinci(
 #endif
           /* WAS: (void) fprintf(fp, "l(\"%lx\",n(\"constant\",[a(\"OBJECT\",\"", id); */
         /* NuSMV: add end */
-        (void) print_node(fp, cuddV(f));
+        (void) dd->print_fun(dd, fp, cuddV(f), dd->env_arg);
         retval = fprintf(fp, "\")],[]))");
       /* NuSMV: added end */
         if (retval == EOF) {
@@ -1485,7 +1485,7 @@ ddDoDumpDDcal(
 #endif
           /* WAS: retval = fprintf(fp, "n%lx = ", id); */
         /* NuSMV: add end */
-	retval &= print_node(fp, cuddV(f));
+	retval &= dd->print_fun(dd, fp, cuddV(f), dd->env_arg);
 	retval &= fprintf(fp, "\n");
 #endif
     /* NuSMV: added end */
