@@ -68,7 +68,7 @@
 
 ******************************************************************************/
 
-#ifdef __STDC__
+#if defined(__STDC__) || defined(_MSC_VER)
 #include <float.h>
 #else
 #define DBL_MAX_EXP 1024
@@ -260,15 +260,15 @@ Cudd_SupersetHeavyBranch(
 {
     DdNode *subset, *g;
 
-    g = Cudd_Not(f);    
+    g = Cudd_Not(f);
     memOut = 0;
     do {
 	dd->reordered = 0;
 	subset = cuddSubsetHeavyBranch(dd, g, numVars, threshold);
     } while ((dd->reordered == 1) && (!memOut));
-    
+
     return(Cudd_NotCond(subset, (subset != NULL)));
-    
+
 } /* end of Cudd_SupersetHeavyBranch */
 
 
@@ -313,7 +313,7 @@ cuddSubsetHeavyBranch(
     st_table *storeTable, *approxTable;
     char *key, *value;
     st_generator *stGen;
-    
+
     if (f == NULL) {
 	fprintf(dd->err, "Cannot subset, nil object\n");
 	dd->errorCode = CUDD_INVALID_ARG;
@@ -519,7 +519,7 @@ ResizeNodeDataPages(void)
   counts.  The procedure  moves the counter to the next page when the
   end of the page is reached and allocates new pages when necessary.]
 
-  SideEffects [Changes the size of minterm pages, page, page index, maximum 
+  SideEffects [Changes the size of minterm pages, page, page index, maximum
   number of pages freeing stuff in case of memory out. ]
 
   SeeAlso     []
@@ -711,7 +711,7 @@ SubsetCountMintermAux(
 	/* store the cofactors */
 	Nv = Cudd_T(N);
 	Nnv = Cudd_E(N);
-	
+
 	Nv = Cudd_NotCond(Nv, Cudd_IsComplement(node));
 	Nnv = Cudd_NotCond(Nnv, Cudd_IsComplement(node));
 
@@ -891,7 +891,7 @@ SubsetCountNodesAux(
     N  = Cudd_Regular(node);
     Nv = Cudd_T(N);
     Nnv = Cudd_E(N);
-    
+
     Nv = Cudd_NotCond(Nv, Cudd_IsComplement(node));
     Nnv = Cudd_NotCond(Nnv, Cudd_IsComplement(node));
 
@@ -1136,7 +1136,7 @@ StoreNodes(
 
 /**Function********************************************************************
 
-  Synopsis    [Builds the subset BDD using the heavy branch method.] 
+  Synopsis    [Builds the subset BDD using the heavy branch method.]
 
   Description [The procedure carries out the building of the subset BDD
   starting at the root. Using the three different counts labelling each node,
@@ -1263,7 +1263,7 @@ BuildSubsetBdd(
 	    cuddRef(ElseBranch);
 	  }
 	}
-	
+
     }
     else {
         /* recur with the Else branch */
@@ -1303,7 +1303,7 @@ BuildSubsetBdd(
     Cudd_RecursiveDeref(dd, ThenBranch);
     Cudd_RecursiveDeref(dd, ElseBranch);
 
-      
+
     if (neW == NULL)
 	return(NULL);
     else {
@@ -1325,4 +1325,3 @@ BuildSubsetBdd(
         return(neW);
     }
 } /* end of BuildSubsetBdd */
-
