@@ -296,7 +296,11 @@ Mtr_MakeGroup(
 
     /* Here last != NULL and low + size <= last->low + last->size. */
     if (low + size - 1 >= (unsigned int) last->low &&
-	low + size <= (unsigned int) (last->low + last->size)) {
+        /* NuSmv change begins */
+	/* low + size <= (unsigned int) (last->low + last->size)) { */
+	low + size <  (unsigned int) (last->low + last->size)) {
+        /* Backporing from 2.5.0, closing mantis issue 0003936 */
+        /* NuSmv change ends */
 	/* Trying to cut an existing group: not allowed. */
 	return(NULL);
     }
